# zib -- zzznowman's IRC bot
# Copyright (C) 2006  Fabian Pietsch <fabian@zzznowman.dyndns.org>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Helper functions

package ZIB;
use strict;
use warnings;
use vars qw($VERSION @ISA @EXPORT_OK @EXPORT %loglevels $loglevel);
use POSIX qw(strftime);
require Exporter;

$VERSION = 20060522.1;
@ISA = qw(Exporter);
@EXPORT_OK = qw(%loglevels $loglevel logsym2level setloglevel log_msg
                error warning notice info debug
                split_line raw2nuh raw2nick raw2user raw2host);
@EXPORT    = qw($loglevel setloglevel
                error warning notice info debug
                split_line raw2nick raw2user raw2host);

%loglevels = (error => 1, warning => 2, notice => 3, info => 4, debug => 5);
$loglevel = $loglevels{debug};


# Logging

sub logsym2level($)
{
	my ($sym) = @_;
	return ($sym =~ /^\d+$/) ? $sym : ($loglevels{$sym} || 0);
}

sub setloglevel($)
{
	my ($newsym) = @_;
	my $oldlevel = $loglevel;

	if (defined($newsym))
	{
		$loglevel = logsym2level($newsym);
	}

	return $oldlevel;
}

sub log_msg($$@)
{
	my ($logsym, $format, @args) = @_;
	my $msglevel = logsym2level($logsym);
	return if ($msglevel > $loglevel);

	printf("<%d> %s" . $format . "\n", $msglevel,
	       strftime("[%H:%M:%S] ", localtime), @args);
}

sub error($@)   { unshift(@_, 'error');   &log_msg; }
sub warning($@) { unshift(@_, 'warning'); &log_msg; }
sub notice($@)  { unshift(@_, 'notice');  &log_msg; }
sub info($@)    { unshift(@_, 'info');    &log_msg; }
sub debug($@)   { unshift(@_, 'debug');   &log_msg; }


# Input conversion

sub split_line($)
{
	my ($line) = @_;

	# Remove whitespace.
	chomp($line);
	$line =~ s/^\s+|\s+$//g;
	$line =~ s/\s+/ /g;

	# Split into words.
	return split(/ /, $line);
}

sub raw2nuh($)
{
	my ($raw) = @_;
	my ($nick, $user, $host) = $raw;

	if ($raw =~ /^([^!@]*)(?:!([^@]*))?(?:@(.*))?$/)
	{
		$nick = $1;
		$user = $2;
		$host = $3;
	}

	return ($nick, $user, $host);
}

sub raw2nick($)
{
	return (&raw2nuh)[0];
}

sub raw2user($)
{
	return (&raw2nuh)[1];
}

sub raw2host($)
{
	return (&raw2nuh)[2];
}

1;
