# zib -- zzznowman's IRC bot
# Copyright (C) 2006  Fabian Pietsch <fabian@zzznowman.dyndns.org>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Channel objects containment

package ZIB::ChannelList;
use strict;
use warnings;
use vars qw($VERSION);
use ZIB;

$VERSION = 20060522.1;

sub new($;$)
{
	my ($class, $connection) = @_;

	my $self = {
	  connection => $connection,
	  channels   => {}
	};
	return bless($self, $class);
}

sub conn($) { return $_[0]->{connection} }

sub chans($) {
	my $csref = $_[0]->{channels};
	return (wantarray() ? values(%{$csref}) : $csref);
}

sub chan($$)
{
	my ($self, $name) = @_;

	return $self->chans()->{$name};
}

sub add_chans($@)
{
	my ($self, @newchans) = @_;
	my $csref = $self->chans();
	my @channames = ();

	foreach my $chan (@newchans)
	{
		my $channame = $chan->name();

		if (defined($csref->{$channame}))
		{
			warning("Warning: channel $channame already in list, skipping");
			next;
		}

		$csref->{$channame} = $chan;
		push(@channames, $channame);
	}

	return @channames;
}

sub remove_chans($@)
{
	my ($self, @oldchans) = @_;
	my $csref = $self->chans();
	my @channames = ();

	foreach my $chan (@oldchans)
	{
		my ($inlist, $channame);

		if (UNIVERSAL::isa($chan, 'ZIB::Channel'))
		{
			$channame = $chan->name();
			my $candidate = $csref->{$channame};
			$inlist = (defined($candidate) && ($candidate == $chan));
		}
		else
		{
			my $realchan = $self->chan($chan);
			if (defined($realchan))
			{
				$inlist = 1;
				$channame = $realchan->name();
			}
			else
			{
				$inlist = 0;
				$channame = $chan;
			}
		}

		unless ($inlist)
		{
			warning("Warning: channel $channame not in list, skipping");
			next;
		}

		delete($csref->{$channame});
		push(@channames, $channame);
	}

	return @channames;
}

sub clear($)
{
	my ($self) = @_;
	my $csref = $self->chans();

	delete($csref->{keys %$csref});
}

sub join_chans($@)
{
	my ($self, @newchans) = @_;
	my $conn = $self->conn();

	my @channames = &add_chans;
	return unless (scalar(@channames));

	info("Trying to join channel%s %s",
	     $#channames == 0 ? '' : 's', join(',', @channames));
	foreach my $channame (@channames)
	{
		$conn->join($channame);
	}

	return @channames;
}

sub part_chans($@)
{
	my ($self, @oldchans) = @_;
	my $conn = $self->conn();

	my @channames = &remove_chans;
	return unless (scalar(@channames));

	info("Trying to part channel%s %s",
	     $#channames == 0 ? '' : 's', join(',', @channames));
	foreach my $channame (@channames)
	{
		$conn->part($channame);
	}

	return @channames;
}

sub part_all_chans($)
{
	my ($self) = @_;

	info("About to part all channels");
	$self->part_chans(values(%{$self->chans()}));
}

1;
