# zib -- zzznowman's IRC bot
# Copyright (C) 2006  Fabian Pietsch <fabian@zzznowman.dyndns.org>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Request handlers

package ZIB::RequestHandlers;
use strict;
use warnings;
use vars qw($VERSION);
use ZIB;
use ZIB::Request;

$VERSION = 20060522.1;

# Use CrudeLeo if it is available.
eval { require CrudeLeo; CrudeLeo->import(); };

# Do a fresh start.
ZIB::Request->unregister_all_types();
ZIB::Request->emptyreplies(qw{:'( zilch nada nix nil null naught nought zero nothing});

# Request types: dict, leo (using CrudeLeo)
ZIB::Request->register_types(sub {
	my ($self) = @_;
	my ($type, $via, $who, @args) =
	   ($self->type(), $self->via(), $self->who(), $self->args());

	unless (defined(&crudeleo))
	{
		$self->queue_reply('CrudeLeo module not loaded');
		$self->ready(1);
		return;
	}

	my @results = crudeleo("@args", 10);
	my ($width1, $width2) = (1)x2;

	foreach my $pair (@results)
	{
		my ($len1, $len2) = map { length } (@$pair);

		$width1 = $len1 if ($len1 > $width1);
		$width2 = $len2 if ($len2 > $width2);
	}

	$width1++; $width2++;

	foreach my $pair (@results)
	{
		$self->queue_reply(
		  sprintf("%-${width1}s - %${width2}s", @$pair));
	}

	$self->ready(1);
}, qw(dict leo));

# Request types: hello zib
ZIB::Request->register_types(sub {
	my ($self) = @_;
	my $nick = raw2nick($self->who());

	$self->queue_reply("Hello $nick, I'm zib, your friendly bot.");
	$self->ready(1);
}, qw(hello zib));

1;
